# Tool Reference

**16 Packs. 104 Tools.**

Complete reference of all built-in tool packs and functions.

## Tool Packs

| Pack | Description | Tool Count | Credits | Tools |
|------|-------------|---|---------|-------|
| [**brave**](brave.md) | Web search with AI summaries. | 7 | [brave-search-mcp-server](https://github.com/brave/brave-search-mcp-server) (MIT) | `image`, `local`, `news`, `search`, `search_batch`, `summarize`, `video` |
| [**code**](code.md) | Semantic code search. | 3 | [ChunkHound](https://github.com/chunkhound/chunkhound) (MIT) | `search`, `search_batch`, `status` |
| [**context7**](context7.md) | Library documentation lookup. | 2 | [context7](https://github.com/upstash/context7) (MIT) | `doc`, `search` |
| [**convert**](convert.md) | Convert PDF, Word, PowerPoint, Excel to Markdown. | 5 | MIT | `auto`, `excel`, `pdf`, `powerpoint`, `word` |
| [**db**](db.md) | SQL database queries. | 3 | [mcp-alchemy](https://github.com/runekaagaard/mcp-alchemy) (MPL 2.0) | `query`, `schema`, `tables` |
| [**diagram**](diagram.md) | Generate Mermaid, PlantUML, D2 diagrams. | 11 | [Kroki](https://kroki.io/) (MIT) | `batch_render`, `generate_source`, `get_diagram_instructions`, `get_diagram_policy`, `get_output_config`, `get_playground_url`, `get_render_status`, `get_template`, `list_providers`, `render_diagram`, `render_directory` |
| [**excel**](excel.md) | Full Excel control. | 24 | [openpyxl](https://github.com/theorchard/openpyxl) (MIT) | `add_sheet`, `cell_range`, `cell_shift`, `copy_range`, `create`, `create_table`, `delete_cols`, `delete_rows`, `formula`, `formulas`, `hyperlinks`, `info`, `insert_cols`, `insert_rows`, `merged_cells`, `named_ranges`, `read`, `search`, `sheets`, `table_data`, `table_info`, `tables`, `used_range`, `write` |
| [**file**](file.md) | Secure file operations with path boundary enforcement. | 10 | MIT | `copy`, `delete`, `edit`, `info`, `list`, `move`, `read`, `search`, `tree`, `write` |
| [**firecrawl**](firecrawl.md) | Web scraping and crawling. | 8 | [firecrawl](https://github.com/mendableai/firecrawl) (AGPL-3.0) | `crawl`, `crawl_status`, `deep_research`, `extract`, `map_urls`, `scrape`, `scrape_batch`, `search` |
| [**ground**](ground.md) | Grounded search with sources. | 5 | [Google Gemini](https://ai.google.dev/) (MIT) | `dev`, `docs`, `reddit`, `search`, `search_batch` |
| [**llm**](llm.md) | AI-powered data transformation. | 1 | MIT | `transform` |
| [**ot**](ot.md) | Introspection and management tools. | 10 | MIT | `aliases`, `config`, `health`, `help`, `notify`, `packs`, `reload`, `snippets`, `stats`, `tools` |
| [**package**](package.md) | Package version lookup and security audits. | 4 | MIT | `audit`, `npm`, `pypi`, `version` |
| [**ripgrep**](ripgrep.md) | Fast regex file search. | 4 | [ripgrep](https://github.com/BurntSushi/ripgrep) (MIT) | `count`, `files`, `search`, `types` |
| [**scaffold**](scaffold.md) | Extension scaffolding. | 3 | MIT | `create`, `list_extensions`, `templates` |
| [**web**](web.md) | Fetch and extract web content. | 2 | [trafilatura](https://github.com/adbar/trafilatura) (Apache 2.0) | `fetch`, `fetch_batch` |
| | **Total** | **104** | | |


